<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>O SMTube...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Informacje</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Tłumacze</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licencja</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>Przeglądarka YouTube%1 dla SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Wersja: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Wydanie przenośne</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Używa Qt %1 (kompilowany z %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Odwiedź naszą stronę, aby uzyskać informacje o aktualizacjach:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Wielu ludzi ma swój udział w tłumaczeniach.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Możesz również pomóc w tłumaczeniu SMTube na twój własny język.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Odwiedź %1 aby dołączyć do zespołu tłumaczeń.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Kliknij tutaj, aby poznać tłumaczy z zespołów Transifex</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="125"/>
        <source>Home</source>
        <translation>Strona główna</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="128"/>
        <source>Navigation</source>
        <translation>Nawigacja</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="136"/>
        <source>Zoom +</source>
        <translation>Powiększenie +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="140"/>
        <source>Zoom -</source>
        <translation>Powiększenie -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="144"/>
        <source>&amp;Quit</source>
        <translation>&amp;Wyjdź</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Nawigacja</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="159"/>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>Toolbar</source>
        <translation>Pasek narzędzi</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="164"/>
        <source>Statusbar</source>
        <translation>Pasek stanu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="168"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="176"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="179"/>
        <source>&amp;Update the YouTube code</source>
        <translation>&amp;Uaktualnij kod YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="185"/>
        <source>About this &amp;release</source>
        <translation>Informacje o &amp;wydaniu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="190"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;O SMTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="298"/>
        <source>Download video using an external service</source>
        <translation>Pobierz film za pomocą usługi zewnętrznej</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="299"/>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="527"/>
        <source>Connection failed</source>
        <translation>Połączenie nie powiodło się</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="528"/>
        <source>The video you requested needs to open a HTTPS connection.</source>
        <translation>Wideo, które chcesz obejrzeć potrzebuje nawiązania połączenia HTTPS.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="529"/>
        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
        <translation>Niestety potrzebny do tego komponent OpenSSL, nie jest dostępny w twoim systemie.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="534"/>
        <source>No video found</source>
        <translation>Nie znaleziono żadnego wideo</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="535"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Nie było możliwe znalezienie URL dla tego wideo.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="545"/>
        <location filename="../browserwindow.cpp" line="553"/>
        <source>Problems with YouTube</source>
        <translation>Problemy z YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="546"/>
        <location filename="../browserwindow.cpp" line="554"/>
        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
        <translation>Niestety z powodu zmian w YouTube, wideo &apos;%1&apos; nie może zostać odtworzone.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="547"/>
        <source>Do you want to update the YouTube code? This may fix the problem.</source>
        <translation>Czy chcesz uaktualnić kod YouTube? To może naprawić ten problem.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="555"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation>Być może aktualizacja tego programu rozwiąże problem.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="574"/>
        <source>About this release</source>
        <translation>O tym wydaniu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="575"/>
        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
        <translation>Z powodu zmian na YouTube, stara wersja SMTube już nie działa.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="576"/>
        <source>This is a new version of SMTube, written from scratch.</source>
        <translation>To jest nowa wersja SMTube, napisana od zera.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="577"/>
        <source>Some functionality is not available yet.</source>
        <translation>Niektóre funkcjonalności nie są jeszcze dostępne.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>Important:</source>
        <translation>Ważne:</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="580"/>
        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
        <translation>Jeśli wideo z VEVO nie odtwarza się, należy użyć opcji %1 w menu Pomoc.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="581"/>
        <source>Update the YouTube code</source>
        <translation>Zaktualizuj kod YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="284"/>
        <source>Loading... %1%</source>
        <translation>Ładowanie... %1%</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>O&amp;gólne</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="108"/>
        <source>&amp;Players</source>
        <translation>&amp;Odtwarzacze</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="156"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="121"/>
        <source>Up</source>
        <translation>Do góry</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Odtwarzanie</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Preferowana jakość:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="167"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="204"/>
        <source>A&amp;dd predefined players</source>
        <translation>&amp;Dodaj predefiniowane odtwarzacze</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="240"/>
        <source>&amp;Interface</source>
        <translation>&amp;Interfejs</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="248"/>
        <source>&amp;Style:</source>
        <translation>&amp;Styl:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="284"/>
        <source>Font:</source>
        <translation>Czcionka:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>C&amp;hange...</source>
        <translation>Zmień... (&amp;h)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Pobierz film za pomocą usługi &amp;zewnętrznej</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="132"/>
        <source>Down</source>
        <translation>W dół</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Default</source>
        <translation>Domyślnie</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Kliknij aby wybrać plik lub katalog</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>Otwórz w &amp;YouTube</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Zapisz link...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>Kopiuj &amp;link do schowka</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Otwórz link w tym oknie</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>&amp;Kopiuj tekst do schowka</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Otwórz link w &amp;nowym oknie</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Odtwarzaj z</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>Odtwarzaj &amp;dźwięk z</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>&amp;Odtwarzaj z %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation>Odtwarzaj &amp;dźwięk z %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation>Odtwarzaj wideo za pomocą przeglądarki &amp;internetowej</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Edytuj odtwarzacz</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nazwa:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>Plik wykonywalny:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Paramatry:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Ten odtwarzacz obsługuje strony wideo</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Ten odtwarzacz może odtwarzać telewizję online</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Preferowana &amp;jakość:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Dodaj do &amp;menu:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Wideo i dźwięk</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Domyślnie</translation>
    </message>
</context>
</TS>
